package cn.hanghui.outapi.platform.tenant.entity.po;

import cn.hanghui.outapi.platform.common.entity.po.Base;
import cn.hanghui.outapi.platform.tenant.entity.dto.ManualInIdCardAuthDto;
import cn.hanghui.outapi.platform.tenant.entity.dto.ZoloConfigDto;
import cn.hanghui.outapi.platform.tenant.typehandle.IntegerTypeHandler;
import cn.hanghui.outapi.platform.tenant.typehandle.LongTypeHandler;
import cn.hanghui.outapi.platform.tenant.typehandle.ManualInIdCardAuthHandler;
import cn.hanghui.outapi.platform.tenant.typehandle.StringTypeHandler;
import cn.hanghui.outapi.platform.tenant.typehandle.ZoloConfigDtoHandler;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.TableField;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;
import java.time.LocalDate;
import java.time.LocalTime;


/**
 * <p>
 * 设备
 * </p>
 *
 * @author wxg
 * @since 2023-12-29
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName(value = "device_template", autoResultMap = true)
@ApiModel(value = "DeviceTemplate对象", description = "设备")
public class DeviceTemplate extends Base {

    @ApiModelProperty(value = "模版名称")
    @TableField("template_name")
    private String templateName;

    //基本信息配置
    @ApiModelProperty(value = "应用类型id")
    private Long applicationTypeId;
    @ApiModelProperty(value = "设备型号(硬件)id")
    private Long deviceModelHardwareId;
    @ApiModelProperty(value = "设备型号(环境)id")
    private Long deviceModelEnvironmentId;
    @ApiModelProperty(value = "系统类型 1-蚂蚁OS 2-非蚂蚁OS")
    private Integer systemTypeCode;


    //应用配置
    @ApiModelProperty(value = "应用通信模式 1-HTTP 2-WS 3-serialPort")
    private Integer communicationMode;
    @ApiModelProperty(value = "websocket地址")
    private String wsAddress;
    @ApiModelProperty(value = "串口地址serialPort")
    private String communicationSerialPort;

    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.LinkageCheckModeEnum
     */
    @ApiModelProperty(value = "联动平台校验模式 1-通用 2-预检查模式")
    private Integer linkageCheckMode;


    //支付宝刷脸启动核点配置
    @ApiModelProperty(value = "服务编码 默认1-BPaaSVerifyID 2-BPaaSOpenRocket")
    private Integer serverCode;
    @ApiModelProperty(value = "商户id tenantId")
    private Long tenantId;
    @ApiModelProperty(value = "场景id")
    private Long sceneId;
    /**
     * 模式 mode: public/close/elasticity 三个参数分别代表 开放/封闭/弹性
     */
    private String mode;
    @ApiModelProperty(value = "用户库id")
    private Long userLibId;
    @ApiModelProperty(value = "采集页倒计时时间 5s-100s 默认值30s")
    private Integer collectCountdownTime;
    @ApiModelProperty(value = "识别超时时间 3s-15s 默认值5s")
    private Integer identifyTimeout;
    @ApiModelProperty(value = "是否语音播报 默认值true")
    private Boolean voicePlaySwitch;
    @ApiModelProperty(value = "是否显示人脸跟随框 默认值true")
    private Boolean faceFollowBoxSwitch;
    @ApiModelProperty(value = "进场检测最大距离 500mm-1200mm 默认750")
    private Integer entryDetectionMaxDistance;
    @ApiModelProperty(value = "识别态最大检测距离 500mm-1200mm 默认750")
    private Integer identifyDetectionMaxDistance;
    @ApiModelProperty(value = "识别态最大识别距离 500mm-1200mm 默认750")
    private Integer identifyMaxDistance;
    @ApiModelProperty(value = "是否生成离线ftoken 默认值true")
    private Boolean smileOfflineSwitch;
    @ApiModelProperty(value = "是否开启墨镜识别的文案提示 默认值false")
    private Boolean sunglassesIdentifyTipsSwitch;
    @ApiModelProperty(value = "是否开启帽子识别的文案提示 默认值false")
    private Boolean hatIdentifyTipsSwitch;
    @ApiModelProperty(value = "是否开启刘海识别的文案提示 默认值false")
    private Boolean bangsIdentifyTipsSwitch;
    @ApiModelProperty(value = "是否开启口罩识别的文案提示 默认值false")
    private Boolean maskIdentifyTipsSwitch;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.EntryFaceModeEnum
     */
    @ApiModelProperty(value = "进场刷脸模式 默认：normal")
    private String entryFaceMode;
    @ApiModelProperty(value = "通行方式: 通用(normal) 进站刷脸全量通行(inStation)  出站刷脸全量通行(outStation)")
    private String passWay;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.CameraTypeEnum
     */
    @ApiModelProperty(value = "摄像头类型 IR-双目  3D-3D结构光 ")
    private String cameraType;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.CameraBrandEnum
     */
    @ApiModelProperty(value = "品牌 Normal-通用   Mario-马里奥")
    private String cameraBrand;
    @ApiModelProperty(value = "zoloConfig摄像头配置 ZoloConfigDto")
    @TableField(value = "zolo_config", typeHandler = ZoloConfigDtoHandler.class)
    private ZoloConfigDto zoloConfig;


    //采集配置
    @ApiModelProperty(value = "是否启用支付宝人脸能力 默认：true")
    private Boolean useAlipayFace;
    @ApiModelProperty(value = "刷脸模式: 点击/自动 click/auto  默认 auto")
    private String faceMode;
    @ApiModelProperty(value = "点击刷脸按钮文本  默认 点击开始刷脸核验")
    private String clickButtonText;
    @ApiModelProperty(value = "是否启用身份证功能 默认：true")
    private Boolean useIdcard;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.IdCardReaderBrandEnum
     */
    @ApiModelProperty(value = "身份证阅读器品牌 IdCardReaderBrandEnum")
    private Integer idCardReaderBrand;
    @ApiModelProperty(value = "是否解析身份证照片 0-否 1-是 默认-1")
    private Integer analysisPhoto;
    @ApiModelProperty(value = "是否解析身份证指纹 0-否 1-是 默认-0")
    private Integer analysisFingerprint;
    @ApiModelProperty(value = "是否人证比对 默认：false")
    private Boolean usePersonCard;
    @ApiModelProperty(value = "同证间隔时间 取值范围0-20 默认-7")
    private Integer idCardInterval;
    @ApiModelProperty(value = "是否启用二维码功能 默认：true")
    private Boolean useQrcode;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.QrCodeReaderBrandEnum
     */
    @ApiModelProperty(value = "二维码读头品牌 QrCodeReaderBrandEnum")
    private Integer qrCodeReaderBrand;
    @ApiModelProperty(value = "二维码读头通信模式 1-虚拟串口 2-串口serialPort")
    private Integer qrCodeReaderCommunicationMode;
    @ApiModelProperty(value = "二维码读头串口地址serialPort")
    private String qrCodeReaderSerialPort;
    @ApiModelProperty(value = "同码间隔时间 取值范围0-20 默认-7")
    private Integer qrCodeInterval;
    @ApiModelProperty(value = "刷证/码延时(毫秒)： x/ms")
    private Integer openDelayTime;
    @ApiModelProperty(value = "是否开启护照机")
    private Boolean isOpenPassport;
    @ApiModelProperty(value = "是否开启手动输入证件号 默认false")
    private Boolean manualInIdCard;
    @ApiModelProperty(value = "开启手动输入证件号的密钥信息")
    @TableField(value = "manual_in_id_card_auth", typeHandler = ManualInIdCardAuthHandler.class)
    private ManualInIdCardAuthDto manualInIdCardAuth;
    @ApiModelProperty(value = "二维码是否人证比对 默认：false")
    private Boolean qrCodeUsePersonCard;
    @ApiModelProperty(value = "护照是否人证比对 默认：false")
    private Boolean passportUsePersonCard;
    @ApiModelProperty(value = "手动输入证件号是否人证比对 默认：false")
    private Boolean manualInUsePersonCard;

    //三方接口接入配置
    @ApiModelProperty(value = "是否启用核验接口 默认：false")
    private Boolean useLinkage;
    @ApiModelProperty(value = "联动平台地址")
    private String linkageAds;
    @ApiModelProperty(value = "核验接口数据是否加解密 默认true")
    private Boolean checkVerifyEncryptSwitch;
    @ApiModelProperty(value = "核验接口数据是否加解密appKey")
    private String checkVerifyEncryptAppKey;
    @ApiModelProperty(value = "核验接口数据是否加解密appSecrete")
    private String checkVerifyEncryptAppSecret;
    @ApiModelProperty(value = "核验接口数据是否加解密PrivateKey")
    private String checkVerifyEncryptPrivateKey;
    @ApiModelProperty(value = "核验接口失败重试次数 默认-1")
    private Integer checkVerifyRetryTimes;
    @ApiModelProperty(value = "核验接口超时提示语 默认-核验接口超时")
    private String checkVerifyTimeoutTips;
    @ApiModelProperty(value = "核验接口失败提示语 默认-核验接口失败")
    private String checkVerifyFailedTips;
    @ApiModelProperty(value = "核验接口超时时间：4s")
    private Integer linkTimeout;

    @ApiModelProperty(value = "启用匿名入库接口 默认false")
    private Boolean authVerifiedFacein;
    @ApiModelProperty(value = "匿名入库地址")
    private String anonymousInterfaceUrl;
    @ApiModelProperty(value = "匿名入库数据是否加解密 默认true")
    private Boolean anonymousEncryptSwitch;
    @ApiModelProperty(value = "匿名入库数据是否加解密appKey")
    private String anonymousEncryptAppKey;
    @ApiModelProperty(value = "匿名入库数据是否加解密appSecrete")
    private String anonymousEncryptAppSecret;
    @ApiModelProperty(value = "匿名入库数据是否加解密PrivateKey")
    private String anonymousEncryptPrivateKey;
    @ApiModelProperty(value = "匿名入库接口失败重试次数 默认-2")
    private Integer anonymousRetryTimes;
    @ApiModelProperty(value = "匿名入库接口超时时间：10s")
    private Integer anonymousTimeout;

    @ApiModelProperty(value = "是否开启纯采集匿名入库 false-关闭 true-开启 默认false")
    private Boolean anonymousStorage;
    @ApiModelProperty(value = "纯采集匿名入库地址")
    private String anonymousStorageUrl;

    @ApiModelProperty(value = "启用商户平台接口 false-关闭 true-开启 默认true")
    private Boolean tenantSwitch;
    @ApiModelProperty(value = "商户平台数据是否加解密 默认true")
    private Boolean tenantEncryptSwitch;
    @ApiModelProperty(value = "商户平台数据是否加解密appKey")
    private String tenantEncryptAppKey;
    @ApiModelProperty(value = "商户平台数据是否加解密appSecrete")
    private String tenantEncryptAppSecret;
    @ApiModelProperty(value = "商户平台数据是否加解密PrivateKey")
    private String tenantEncryptPrivateKey;
    @ApiModelProperty(value = "商户平台接口失败重试次数 默认-1")
    private Integer tenantRetryTimes;
    @ApiModelProperty(value = "商户平台接口超时提示语 默认-商户平台请求超时")
    private String tenantTimeoutTips;
    @ApiModelProperty(value = "商户平台接口失败提示语 默认-商户平台请求失败")
    private String tenantFailedTips;
    @ApiModelProperty(value = "商户平台接口超时时间：5s")
    private Integer tenantTimeout;

    @ApiModelProperty(value = "（new）启用三要素获取特殊码接口 默认：false-否")
    private Boolean specialCodeSwitch;
    @ApiModelProperty(value = "（new）三要素获取特殊码接口地址")
    private String specialCodeUrl;
    @ApiModelProperty(value = "（new）三要素获取特殊码接口超时时间：5s")
    private Integer specialCodeTimeout;
    @ApiModelProperty(value = "（new）三要素获取特殊码接口超时提示语 默认-三要素获取特殊码接口请求超时")
    private String specialCodeTimeoutTips;
    @ApiModelProperty(value = "（new）三要素获取特殊码接口失败提示语 默认-三要素获取特殊码接口请求失败")
    private String specialCodeFailedTips;
    @ApiModelProperty(value = "（new）特殊码标识（首位/前缀）")
    private String specialCodePrefix;


    //结果页配置
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.ResultPageTemplateEnum
     */
    @ApiModelProperty(value = "结果页模版 1-通用版 2-悬浮版")
    private Integer resultPageTemplate;
    @ApiModelProperty(value = "刷脸失败是否静默显示 false-关闭 true-开启 默认false")
    private Boolean compareSilentDisplay;
    @ApiModelProperty(value = "刷脸失败静默时长 默认2s")
    private Integer compareSilentDisplayTime;
    @ApiModelProperty(value = "刷脸失败顶部文字 默认：未查询到人脸信息")
    private String compareTopTitle;
    @ApiModelProperty(value = "刷脸成功结果页时长 1-10 默认值2")
    private Integer successPageTime;
    @ApiModelProperty(value = "成功语音 默认: 请通行")
    private String sucVoice;
    @ApiModelProperty(value = "成功文字 默认: 请通行")
    private String sucText;
    @ApiModelProperty(value = "是否根据开门次数决定显示时长 false-关闭 true-开启 默认false")
    private Boolean showDisplayTimeByOpenTimesSwitch;
    @ApiModelProperty(value = "单次开门时长 默认2")
    private Integer onceOpenDoorTime;
    @ApiModelProperty(value = "刷脸失败结果页时长 1-10 默认值5")
    private Integer failPageTime;
    @ApiModelProperty(value = "失败文字 默认: 比对失败,请联系现场工作人员")
    private String failText;
    @ApiModelProperty(value = "失败语音 默认: 比对失败,请联系现场工作人员")
    private String failVoice;
    @ApiModelProperty(value = "默认单选页时长 默认120")
    private Integer singlePageTime;
    @ApiModelProperty(value = "默认多选页时长 默认120")
    private Integer multiPageTime;
    @ApiModelProperty(value = "默认等待页时长 默认120")
    private Integer waitPageTime;


    @ApiModelProperty(value = "1:1比对是否显示提醒页面 默认：true")
    private Boolean oneToOneTipsSwitch;
    @ApiModelProperty(value = "1:1比对提醒文字 默认：请面向屏幕刷脸")
    private String oneToOneTips;
    @ApiModelProperty(value = "1:1比对提醒语音")
    private String oneToOneVoice;
    @ApiModelProperty(value = "1:1比对超时时间 默认：15s")
    private Integer oneToOneTimeout;

    @ApiModelProperty(value = "是否显示通行统计 默认false")
    private Boolean showTopBar;
    @ApiModelProperty(value = "顶部栏左边显示内容")
    private String leftTopBarText;
    @ApiModelProperty(value = "顶部栏右边显示内容")
    private String rightTopBarText;

    // 硬件模组配置
    @ApiModelProperty(value = "开门信号: 继电器/RS232 default/RS232 默认：default")
    private String useSerialPort;
    @ApiModelProperty(value = "RS232开门信号串口地址")
    private String doorSerialPort;

    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.RelayOpenModelEnum
     */
    @ApiModelProperty(value = "继电器开门模式 1-开-闭信号 2-开-门磁-闭信息")
    private Integer relayOpenModel;
    @ApiModelProperty(value = "门磁串口地址")
    private String doorSerialPortAddress;
    @ApiModelProperty(value = "门磁超时时间（s）")
    private Integer gateTimeOut;
    @ApiModelProperty(value = "补光灯: 自动 auto 默认:auto")
    private String lightMode;
    @ApiModelProperty(value = "开闭时间间隔（s）")
    private Integer openCloseInterval;
    @ApiModelProperty(value = "信号间间隔（s）")
    private Integer signalInterval;

    //推送配置
    @ApiModelProperty(value = "应用状态推送地址")
    private String heartTrackingUrl;
    @ApiModelProperty(value = "在线日志推送地址")
    private String logPushUrl;
    @ApiModelProperty(value = "进出记录推送地址")
    private String transitPushUrl;


    //功能配置
    @ApiModelProperty(value = "是否开启年龄限制")
    private Boolean isOpenAgeLimit;
    @ApiModelProperty(value = "限制区间-开始年龄")
    private Integer limitSectionStart;
    @ApiModelProperty(value = "限制区间-结束年龄")
    private Integer limitSectionEnd;
    @ApiModelProperty(value = "禁止进入文本 默认：未满18岁禁止进入")
    private String ageForbidText;
    @ApiModelProperty(value = "门磁信号推送地址")
    @JsonProperty("GMAddress")
    @TableField("gm_address")
    private String GMAddress;
    @ApiModelProperty(value = "是否推送门磁信号")
    @TableField("is_push_gm")
    private Boolean isPushGM;
    @ApiModelProperty(value = "门磁信号推送频率")
    @JsonProperty("GMFrequency")
    @TableField("gm_frequency")
    private Integer GMFrequency;
    @ApiModelProperty(value = "是否推送失败记录")
    private Boolean pushFailedRecordSwitch;

    //系统配置
    @ApiModelProperty(value = "设备管理员密码")
    private String mpassword;
    @ApiModelProperty(value = "语音音量 0-100 默认值80")
    private Integer volume;
    @ApiModelProperty(value = "隐藏底部导航栏 默认: false")
    private Boolean hideNavigationBar;
    @ApiModelProperty(value = "禁止下拉通知栏 默认: false")
    private Boolean forbidPullDown;
    @ApiModelProperty(value = "首页图片")
    private String homePageUrl;
    @ApiModelProperty(value = "过渡图片")
    private String transitionPageUrl;
    @ApiModelProperty(value = "应用是否自启动")
    private Boolean autoLaunch;


    //TODO。。。弃用字段
    @Deprecated
    @TableField("use_entry_detector")
    private Boolean useEntryDetector;
    /**
     * 是否抓拍人脸 默认：false
     */
    @Deprecated
    private Boolean isCaptureFace;
    /**
     * need1V1是否使用支付宝刷证提示页 默认：true
     */
    @Deprecated
    private Boolean isNeed1V1;

    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.UserOutputModeEnum
     */
    @Deprecated
    @ApiModelProperty(value = "用户信息输出模式  NoOutput:不输出（默认）， AnalogSignal:阅读器模拟信号")
    private String userOutputMode;

    @Deprecated
    @ApiModelProperty(value = "RS232默认信号")
    private String signalNo;

    @ApiModelProperty(value = "补光灯亮度 0-200")
    private Integer ledBrightness;

    @ApiModelProperty(value = "（new）开启黑名单 默认：false-否")
    private Boolean userBlacklistSwitch;
    @ApiModelProperty(value = "（new）是否阻止通行 默认：true-是")
    private Boolean forbidPassSwitch;
    @ApiModelProperty(value = "（new）阻止通行的文本 默认：禁止通行")
    private String forbidPassText;
    @ApiModelProperty(value = "（new）阻止通信提示语音 默认：禁止通行，请联系管理员")
    private String forbidPassVoice;
    @ApiModelProperty(value = "（new）命中条件 IDENTITY_CARD-身份证 PHONE-手机号 默认：勾选身份证")
    @TableField(value = "user_blacklist_hit_rule", typeHandler = StringTypeHandler.class)
    private List<String> userBlacklistHitRule;
    @ApiModelProperty(value = "（new）是否启用接口拉取 默认：true")
    private Boolean userBlacklistInterfFetchSwitch;
    @ApiModelProperty(value = "（new）接口拉取地址")
    private String userBlacklistInterfUrl;
    @ApiModelProperty(value = "（new）黑名单数据是否加解密 默认true")
    private Boolean userBlacklistEncryptSwitch;
    @ApiModelProperty(value = "（new）核验接口数据是否加解密appKey")
    private String userBlacklistEncryptAppKey;
    @ApiModelProperty(value = "（new）核验接口数据是否加解密appSecrete")
    private String userBlacklistEncryptAppSecret;
    @ApiModelProperty(value = "（new）核验接口数据是否加解密PrivateKey")
    private String userBlacklistEncryptPrivateKey;
//    @ApiModelProperty(value = "（new）是否启用本地名单 默认false")
//    private Boolean userBlacklistOfflineSwitch;
//
//    @ApiModelProperty(value = "（new）本地名单任务id集合")
//    @TableField(value = "user_blacklist_offline_task_id", typeHandler = LongTypeHandler.class)
//    private List<Long> userBlacklistOfflineTaskId;
    /**
     * @see cn.hanghui.outapi.platform.tenant.entity.enums.PushFailedRecordTypeEnum
     */
    @ApiModelProperty(value = "（new）推送失败记录类型")
    @TableField(value = "push_failed_record_type", typeHandler = IntegerTypeHandler.class)
    private List<Integer> pushFailedRecordType;

    @ApiModelProperty(value = "verify核验接口失败重试次数 默认2")
    private Integer verifyRetryTimes;
    @ApiModelProperty(value = "verify核验接口超时时间：15s")
    private Integer verifyLinkTimeout;
    @ApiModelProperty(value = "是否开启定时重启 true-是 false-否 默认-false")
    private Boolean scheduledRestart;
    @ApiModelProperty(value = "定时重启时间HH:mm:ss")
    private LocalTime scheduledRestartTime;

    @ApiModelProperty(value = "ic14443-是否启用IC卡ISO14443A功能 false-否（默认） true-是")
    private Boolean ic14443IcCardFunction;
    @ApiModelProperty(value = "ic14443-阅读器品牌 ReaderBrandEnum")
    private Integer ic14443ReaderBrand;
    @ApiModelProperty(value = "ic14443-读取扇区-数字；0-99 默认15")
    private Integer ic14443ReaderSectorNumbers;
    @ApiModelProperty(value = "ic14443-读取块-填写,数字逗号隔开 0,1,2,3 长度100 默认0")
    private String ic14443ReaderBlock;
    @ApiModelProperty(value = "ic14443-读取密钥-填写,默认 FFFFFFFFFFFF 长度100 默认12个F")
    private String ic14443ReaderKey;
    @ApiModelProperty(value = "ic14443-起始偏移量-数字 0-100 默认 0")
    private Integer ic14443StartOffset;
    @ApiModelProperty(value = "ic14443-末尾偏移量-数字 0-100 默认 0")
    private Integer ic14443EndOffset;
    @ApiModelProperty(value = "ic14443-是否人证比对；false-否（默认） true-是")
    private Boolean ic14443PersonCardComparison;
    @ApiModelProperty(value = "ic14443-同卡间隔时间；默认7")
    private Integer ic14443SameCardIntervalTime;
    @ApiModelProperty(value = "ic15693-是否启用IC卡ISO14443A功能 false-否（默认） true-是")
    private Boolean ic15693IcCardFunction;
    @ApiModelProperty(value = "ic15693-阅读器品牌 ReaderBrandEnum")
    private Integer ic15693ReaderBrand;
    @ApiModelProperty(value = "ic15693-读取块-填写,数字逗号隔开 0,1,2,3 长度100 默认0")
    private String ic15693ReaderBlock;
    @ApiModelProperty(value = "ic15693-起始偏移量-数字 0-100 默认 0")
    private Integer ic15693StartOffset;
    @ApiModelProperty(value = "ic15693-末尾偏移量-数字 0-100 默认 0")
    private Integer ic15693EndOffset;
    @ApiModelProperty(value = "ic15693-是否人证比对；false-否（默认） true-是")
    private Boolean ic15693PersonCardComparison;
    @ApiModelProperty(value = "ic15693-同卡间隔时间；默认7")
    private Integer ic15693SameCardIntervalTime;

    @ApiModelProperty(value = "到期日期")
    private LocalDate expirationDate;

    @ApiModelProperty(value = "（new）进出记录滤重时间 默认0 0-120s")
    private Integer inOutFilterRepeatTime;

    @ApiModelProperty(value = "刷脸失败结果页图片配置")
    private String scanFaceFailedPageUrl;

}
